FlutterParsexx_c class

Constructors

FlutterParsexx_c()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseColor2String(Color? color) String?
将颜色转为字符串
parseMinute2TimeOfDay(int time) TimeOfDay
parseString2Color(String? str) Color?
将字符串转回颜色值
parseTimeOfDay2Minute(TimeOfDay time) int